@@ -719,8 +719,10 @@ class Client(commandServer, encrypt, Desktop):
             else:
                 if not self.mountSleepRes(host, userName, userPwd,
                                           res, rpath, uid, gid):
-                    raise ClientError(
-                        _("Failed to mount the Samba volume [%s]") % res)
+                    self.printWARNING(_("Failed to mount the Samba volume [%s]") % res)
+                    continue
+                    # raise ClientError(
+                    #     _("Failed to mount the Samba volume [%s]") % res)
         else:
             return True
 
